@@ -18,7 +18,7 @@
 # You should have received a copy of the GNU General Public License
 # along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
 
-srcdest=${srcdest-}
+. ./config.sh
 . ${srcdest}build-aux/configure-lib.sh
 . ${srcdest}build-aux/trace.sh
 . ${srcdest}build-aux/cc.sh
