@@ -21,7 +21,7 @@
 set -e
 set -u
 
-V=${V-1}
+V=${V-}
 
 if [ "$V" = 2 ]; then
     set -x
@@ -33,7 +33,6 @@ fi
 
 trap 'test -f .log && cat .log' EXIT
 
-srcdest=${srcdest-}
 mes_sources="
 src/gc.c
 src/hash.c
@@ -54,4 +53,5 @@ done
 if test $mes_libc = system; then
     LIBS=-lmes
 fi
-link src/mes
+link bin/mes-$compiler
+cp bin/mes-$compiler bin/mes
