@@ -44,19 +44,27 @@ fi
 
 case "$mes_cpu" in
     arm)
-        stage0_cpu=armv7l;;
+        stage0_arch=40
+        stage0_cpu=armv7l
+        ;;
     x86_64)
-        stage0_cpu=amd64;;
+        stage0_arch=2
+        stage0_cpu=amd64
+        ;;
     x86)
-        stage0_cpu=x86;;
+        stage0_arch=1
+        stage0_cpu=x86
+        ;;
     *)
-        stage0_cpu=$mes_cpu;;
+        stage0_arch=1
+        stage0_cpu=$mes_cpu
+        ;;
 esac
 
-trace "CCLD       ${srcdest}lib/$mes_cpu-mes-$compiler/exit-42.S" $CC\
+trace "CCLD       ${srcdest}lib/$mes_kernel/$mes_cpu-mes-$compiler/exit-42.S" $CC\
       -nostdlib\
       -g\
-      ${srcdest}lib/$mes_cpu-mes-$compiler/exit-42.S\
+      ${srcdest}lib/$mes_kernel/$mes_cpu-mes-$compiler/exit-42.S\
       -o exit-42
 
 trace "TEST       exit-42"
@@ -64,12 +72,18 @@ trace "TEST       exit-42"
 [ $r != 42 ] && echo "  => $r"
 [ $r = 42 ]
 
-trace "HEX2       ${srcdest}lib/$mes_cpu-mes/elf$mes_bits-0exit-42.hex2" $HEX2\
+if $numbered_arch; then
+    stage0_cpu_flag="--Architecture $stage0_arch";
+else
+    stage0_cpu_flag="--architecture $stage0_cpu";
+fi
+
+trace "HEX2       ${srcdest}lib/$mes_kernel/$mes_cpu-mes/elf$mes_bits-0exit-42.hex2" $HEX2\
       --LittleEndian\
-      --architecture $stage0_cpu\
+      $stage0_cpu_flag\
       --BaseAddress 0x1000000\
-      -f ${srcdest}lib/$mes_cpu-mes/elf$mes_bits-0header.hex2\
-      -f ${srcdest}lib/$mes_cpu-mes/elf$mes_bits-0exit-42.hex2\
+      -f ${srcdest}lib/$mes_kernel/$mes_cpu-mes/elf$mes_bits-0header.hex2\
+      -f ${srcdest}lib/$mes_kernel/$mes_cpu-mes/elf$mes_bits-0exit-42.hex2\
       --exec_enable\
       -o 0exit-42
 
@@ -78,13 +92,13 @@ trace "TEST       0exit-42"
 [ $r != 42 ] && echo "  => $r"
 [ $r = 42 ]
 
-trace "HEX2       ${srcdest}lib/$mes_cpu-mes/elf$mes_bits-body-exit-42.hex2" $HEX2\
+trace "HEX2       ${srcdest}lib/$mes_kernel/$mes_cpu-mes/elf$mes_bits-body-exit-42.hex2" $HEX2\
       --LittleEndian\
-      --architecture $stage0_cpu\
+      $stage0_cpu_flag\
       --BaseAddress 0x1000000\
-      -f ${srcdest}lib/$mes_cpu-mes/elf$mes_bits-header.hex2\
-      -f ${srcdest}lib/$mes_cpu-mes/elf$mes_bits-body-exit-42.hex2\
-      -f ${srcdest}lib/$mes_cpu-mes/elf$mes_bits-footer-single-main.hex2\
+      -f ${srcdest}lib/$mes_kernel/$mes_cpu-mes/elf$mes_bits-header.hex2\
+      -f ${srcdest}lib/$mes_kernel/$mes_cpu-mes/elf$mes_bits-body-exit-42.hex2\
+      -f ${srcdest}lib/$mes_kernel/$mes_cpu-mes/elf$mes_bits-footer-single-main.hex2\
       --exec_enable\
       -o body-exit-42
 
@@ -94,10 +108,10 @@ trace "TEST       body-exit-42"
 [ $r = 42 ]
 
 ### FIXME: c&p from exit-42
-trace "CCLD       ${srcdest}lib/$mes_cpu-mes-$compiler/hello-mes.S" $CC\
+trace "CCLD       ${srcdest}lib/$mes_kernel/$mes_cpu-mes-$compiler/hello-mes.S" $CC\
       -nostdlib\
       -g\
-      ${srcdest}lib/$mes_cpu-mes-$compiler/hello-mes.S\
+      ${srcdest}lib/$mes_kernel/$mes_cpu-mes-$compiler/hello-mes.S\
       -o hello-mes
 
 trace "TEST       hello-mes"
@@ -105,12 +119,12 @@ trace "TEST       hello-mes"
 [ $r != 0 ] && echo "  => $r"
 [ $r = 0 ]
 
-trace "HEX2       ${srcdest}lib/$mes_cpu-mes/elf$mes_bits-0hello-mes.hex2" $HEX2\
+trace "HEX2       ${srcdest}lib/$mes_kernel/$mes_cpu-mes/elf$mes_bits-0hello-mes.hex2" $HEX2\
       --LittleEndian\
-      --architecture $stage0_cpu\
+      $stage0_cpu_flag\
       --BaseAddress 0x1000000\
-      -f ${srcdest}lib/$mes_cpu-mes/elf$mes_bits-0header.hex2\
-      -f ${srcdest}lib/$mes_cpu-mes/elf$mes_bits-0hello-mes.hex2\
+      -f ${srcdest}lib/$mes_kernel/$mes_cpu-mes/elf$mes_bits-0header.hex2\
+      -f ${srcdest}lib/$mes_kernel/$mes_cpu-mes/elf$mes_bits-0hello-mes.hex2\
       --exec_enable\
       -o 0hello-mes
 
@@ -119,13 +133,13 @@ trace "TEST       0hello-mes"
 [ $r != 0 ] && echo "  => $r"
 [ $r = 0 ]
 
-trace "HEX2       ${srcdest}lib/$mes_cpu-mes/elf$mes_bits-body-hello-mes.hex2" $HEX2\
+trace "HEX2       ${srcdest}lib/$mes_kernel/$mes_cpu-mes/elf$mes_bits-body-hello-mes.hex2" $HEX2\
       --LittleEndian\
-      --architecture $stage0_cpu\
+      $stage0_cpu_flag\
       --BaseAddress 0x1000000\
-      -f ${srcdest}lib/$mes_cpu-mes/elf$mes_bits-header.hex2\
-      -f ${srcdest}lib/$mes_cpu-mes/elf$mes_bits-body-hello-mes.hex2\
-      -f ${srcdest}lib/$mes_cpu-mes/elf$mes_bits-footer-single-main.hex2\
+      -f ${srcdest}lib/$mes_kernel/$mes_cpu-mes/elf$mes_bits-header.hex2\
+      -f ${srcdest}lib/$mes_kernel/$mes_cpu-mes/elf$mes_bits-body-hello-mes.hex2\
+      -f ${srcdest}lib/$mes_kernel/$mes_cpu-mes/elf$mes_bits-footer-single-main.hex2\
       --exec_enable\
       -o body-hello-mes
 
