@@ -41,13 +41,38 @@ lib/stdlib/exit.c
 lib/stdlib/puts.c
 lib/string/strlen.c
 "
+
+    if test $mes_kernel = gnu; then
+        libc_mini_shared_SOURCES="$libc_mini_shared_SOURCES
+lib/gnu/_exit.c
+lib/gnu/exec-startup-get-data.c
+lib/gnu/fd-get.c
+lib/gnu/fd-write.c
+lib/gnu/io-write.c
+lib/gnu/_write.c
+lib/gnu/hurd-start.c
+lib/gnu/proc-mark-exit.c
+lib/gnu/syscall.c
+lib/gnu/task-get-special-port.c
+lib/gnu/task-terminate.c
+lib/gnu/vm-statistics.c
+lib/mach/mach-init.c
+lib/mach/mach_host_self.S
+lib/mach/mach_msg_trap.S
+lib/mach/mach_reply_port.S
+lib/mach/mach_task_self.S
+lib/mach/mach_thread_self.S
+lib/mach/msg.c
+lib/string/argz-extract.c
+"
+    fi
 fi
 
 libc_mini_SOURCES="$libc_mini_shared_SOURCES"
 
 if test $mes_libc = mes; then
     libc_mini_SOURCES="$libc_mini_SOURCES
-lib/mes/write.c
+lib/mes/mini-write.c
 "
 fi
 
@@ -79,6 +104,11 @@ lib/ctype/isxdigit.c
 lib/posix/write.c
 lib/stdlib/atoi.c
 "
+    if test $mes_kernel = gnu; then
+        libmes_SOURCES="$libmes_SOURCES
+lib/stub/lseek.c
+"
+    fi
     if test $mes_kernel = linux; then
         libmes_SOURCES="$libmes_SOURCES
 lib/linux/lseek.c
@@ -101,7 +131,7 @@ lib/posix/getcwd.c
 lib/posix/getenv.c
 lib/posix/isatty.c
 lib/posix/open.c
-lib/posix/read.c
+lib/posix/buffered-read.c
 lib/posix/setenv.c
 lib/posix/wait.c
 lib/stdio/fgetc.c
@@ -125,6 +155,32 @@ lib/string/strcpy.c
 lib/string/strncmp.c
 "
 
+if test $mes_kernel = gnu; then
+    libc_SOURCES="$libc_SOURCES
+lib/gnu/_open3.c
+lib/gnu/_read.c
+lib/gnu/dir-lookup.c
+lib/gnu/fd-read.c
+lib/gnu/io-read.c
+lib/gnu/malloc.c
+lib/gnu/vm-allocate.c
+lib/stub/access.c
+lib/stub/brk.c
+lib/stub/chmod.c
+lib/stub/clock_gettime.c
+lib/stub/dup2.c
+lib/stub/dup.c
+lib/stub/execve.c
+lib/stub/fork.c
+lib/stub/_getcwd.c
+lib/stub/gettimeofday.c
+lib/stub/ioctl.c
+lib/stub/time.c
+lib/stub/unlink.c
+lib/stub/waitpid.c
+"
+fi
+
 if test $mes_kernel = linux; then
     libc_SOURCES="$libc_SOURCES
 lib/linux/access.c
@@ -215,6 +271,14 @@ lib/linux/stat.c
 "
 fi
 
+if test $mes_kernel = gnu; then
+    libc_tcc_SOURCES="$libc_tcc_SOURCES
+lib/stub/close.c
+lib/stub/rmdir.c
+lib/stub/stat.c
+"
+fi
+
 libc_gnu_SOURCES="
 $libc_tcc_SOURCES
 lib/ctype/isalnum.c
