@@ -20,8 +20,12 @@
 
 set -e
 
-VERSION=0.21
+VERSION=0.22
 srcdir=${srcdir-$(dirname $0)}
+srcdest=
+if test "$srcdir" != "."; then
+    srcdest=$srcdir/
+fi
 . ${srcdest}build-aux/trace.sh
 
 # parse arguments
@@ -35,6 +39,7 @@ while [ $# -gt 0 ]; do
             ;;
         (--build=*)
             build=${1#--build=}
+            host=${host-$build}
             ;;
         (--host=*)
             host=${1#--host=}
@@ -52,12 +57,12 @@ done
 prefix=${prefix-/usr/local}
 mes_libc=${mes_libc-mes}
 courageous=${courageous-false}
-host=${host-$build}
 
-AR=${AR-$(command -v ar)} || true
-BASH=${BASH-$(command -v bash)}
+BASH=${BASH-$(command -v bash || command -v sh)}
 BLOOD_ELF=${BLOOD_ELF-$(command -v blood-elf)}
 CC=${CC-$(command -v gcc)} || true
+CFLAGS=${CFLAGS-}
+CPPFLAGS=${CPPFLAGS-}
 DIFF=${DIFF-$(command -v diff || echo $PWD/pre-inst-env diff.scm)}
 GUILD=${GUILD-$(command -v guild)} || true
 GUILE_TOOLS=${GUILE_TOOLS-$(command -v guile-tools)} || true
@@ -70,14 +75,13 @@ if test ! "$GUILD"; then
 fi
 GUILE=${GUILE-$(command -v guile)} || true
 HEX2=${HEX2-$(command -v hex2)}
+LDPFLAGS=${LDFLAGS-}
 M1=${M1-$(command -v M1)}
 MES_FOR_BUILD=${MES_FOR_BUILD-$(command -v mes || command -v guile || echo mes)}
 GIT=${GIT-$(command -v git)} || true
 PERL=${PERL-$(command -v perl)} || true
 SHELL=${BASH-$SHELL}
 
-MES_SEED=${MES_SEED-../mes-seed}
-
 if test "$srcdir" = .; then
     top_builddir=.
 else
@@ -92,6 +96,14 @@ if test -z "$GUILE" -o "$GUILE" = true; then
 else
     GUILE_EFFECTIVE_VERSION=${GUILE_EFFECTIVE_VERSION-$(guile -c '(display (effective-version))')}
 fi
+
+numbered_arch=false
+mes_tools=named
+if ( $HEX2 --help 2>&1 ) | grep -q "\-\-Architecture 12345"; then
+    numbered_arch=true
+    mes_tools=numbered
+fi
+
 bindir=$(eval echo ${bindir-$prefix/bin})
 datadir=$(eval echo ${datadir-$prefix/share})
 docdir=$(eval echo ${docdir-$datadir/doc/mes})
@@ -110,7 +122,7 @@ subst () {
     -e s,"@PACKAGE_NAME@,$PACKAGE_NAME,"\
     -e s,"@PACKAGE_BUGREPORT@,$PACKAGE_BUGREPORT,"\
     -e s,"@VERSION@,$VERSION,"\
-    -e s,"@bootstrap@,yes,"\
+    -e s,"@bootstrap@,true,"\
     -e s,"@build@,$build,"\
     -e s,"@host@,$host,"\
     -e s,"@compiler@,$compiler,"\
@@ -139,6 +151,7 @@ subst () {
     -e s,"@pkgdatadir@,$pkgdatadir,"\
     -e s,"@sysconfdir@,$sysconfdir,"\
     -e s,"@GUILE_EFFECTIVE_VERSION@,$GUILE_EFFECTIVE_VERSION,"\
+    -e s,"@GUILE_LOAD_PATH@,$GUILE_LOAD_PATH,"\
     -e s,"@V@,$V,"\
     -e s,"@AR@,$AR,"\
     -e s,"@BASH@,$BASH,"\
@@ -155,8 +168,7 @@ subst () {
     -e s,"@M1@,$M1,"\
     -e s,"@M1FLAGS@,$M1FLAGS,"\
     -e s,"@MES_FOR_BUILD@,$MES_FOR_BUILD,"\
-    -e s,"@MES_SEED@,$MES_SEED,"\
-    -e s,"@MES_SEED@,$MES_SEED,"\
+    -e s,"@numbered_arch@,$numbered_arch,"\
     -e s,"@SHELL@,$SHELL,"\
     $1 > $2
 }
@@ -186,6 +198,8 @@ case "$host" in
         mes_kernel=linux;;
     *gnu)
         mes_kernel=gnu;;
+    *freebsd*)
+        mes_kernel=frreebsd;;
     *)
         mes_kernel=linux;;
 esac
@@ -197,16 +211,20 @@ case "$mes_cpu" in
         mes_bits=32;;
 esac
 #
-if $CC --version | grep gcc; then #2>/dev/null; then
+if $CC --version | grep gcc; then
     compiler=gcc
-elif $CC --version | grep tcc; then #2>/dev/null; then
+elif $CC --version | grep tcc; then
     compiler=gcc
 else
     compiler=mescc
+    AR=${AR-$PWD/scripts/mesar}
 fi
 
+AR=${AR-$(command -v ar)} || true
+
 mes_system=$mes_cpu-$mes_kernel-mes
 
+mkdir -p scripts
 subst ${srcdest}build-aux/GNUmakefile.in GNUmakefile
 subst ${srcdest}build-aux/config.sh.in config.sh
 subst ${srcdest}build-aux/bootstrap.sh.in bootstrap.sh
@@ -241,20 +259,22 @@ EOF
 fi
 cat >> include/mes/config.h <<EOF
 #define MES_VERSION "$VERSION"
-#define MES_PKGDATADIR "$pkgdatadir"
 EOF
 
 cat <<EOF
 GNU Mes is configured for
-   compiler: $compiler
-   cpu:      $mes_cpu
-   bits:     $mes_bits
-   libc:     $mes_libc
-   kernel:   $mes_kernel
-   system:   $mes_system
+   compiler:   $compiler
+   cpu:        $mes_cpu
+   bits:       $mes_bits
+   libc:       $mes_libc
+   kernel:     $mes_kernel
+   system:     $mes_system
+   tools:      $mes_tools arch
+   courageous: $courageous
+   bootstrap:  yes
 
 Run:
-  sh build.sh      to build mes
+  sh bootstrap.sh  to bootstrap build mes
   sh check.sh      to check mes
   sh install.sh    to install mes
 EOF
