@@ -122,7 +122,7 @@ extensive examples, including parsers for the Javascript and C99 languages.")
 
 (define-public mes
   (let ((triplet "i686-unknown-linux-gnu")
-        (version "0.21"))
+        (version "0.22"))
     (package
       (name "mes")
       (version version)
@@ -138,8 +138,7 @@ extensive examples, including parsers for the Javascript and C99 languages.")
        `(("mescc-tools" ,mescc-tools)
          ("nyacc" ,nyacc)))
       (native-inputs
-       `(("git" ,git)
-         ("guile" ,guile-2.2)
+       `(("guile" ,guile-2.2)
          ,@(if (string-prefix? "x86_64-linux" (or (%current-target-system)
                                                   (%current-system)))
                ;; Use cross-compiler rather than #:system "i686-linux" to get
@@ -164,7 +163,7 @@ Guile.")
       (license gpl3+))))
 
 (define-public mes.git
- (let ((version "0.21")
+ (let ((version "0.22")
         (revision "0")
         (commit (read-string (open-pipe "git show HEAD | head -1 | cut -d ' ' -f 2" OPEN_READ))))
     (package
