@@ -38,14 +38,16 @@ int errno;
 #define ENOENT   2
 #define EINTR    4
 #define EIO      5
+#define ENXIO    6
 #define E2BIG    7
-#define	ENOEXEC  8
+#define ENOEXEC  8
 #define EBADF    9
 #define	ECHILD  10
 #define EAGAIN  11
 #define ENOMEM  12
 #define EACCES  13
 #define EEXIST  17
+#define EXDEV   18
 #define ENOTDIR 20
 #define EISDIR  21
 #define EINVAL  22
