@@ -20,10 +20,9 @@
 #ifndef __MES_FEATURES_H
 #define __MES_FEATURES_H 1
 
-#if WITH_GLIBC
+#if SYSTEM_LIBC
 #undef __MES_FEATURES_H
 #include_next <features.h>
-#endif // (WITH_GLIBC)
+#endif // (SYSTEM_LIBC)
 
 #endif // __MES_FEATURES_H
-
