@@ -83,4 +83,9 @@
 // make+POSIX
 #define SYS_sigprocmask 0x7e
 
+// tar
+#define SYS_symlink   0x53
+#define SYS_readlink  0x55
+#define SYS_mknod     0x0e
+
 #endif // __MES_LINUX_X86_SYSCALL_H
