@@ -20,21 +20,26 @@
 #ifndef __MES_LOCALE_H
 #define __MES_LOCALE_H 1
 
-#if WITH_GLIBC
+#if SYSTEM_LIBC
 #ifndef _GNU_SOURCE
 #define _GNU_SOURCE
 #endif
 #undef __MES_LOCALE_H
 #include_next <locale.h>
 
-#else // ! WITH_GLIBC
+#else // ! SYSTEM_LIBC
 
+// *INDENT-OFF*
 #ifndef LC_ALL
-#define LC_ALL     "LC_ALL"
-#define LC_NUMERIC "LC_NUMERIC"
+#define LC_CTYPE   0
+#define LC_NUMERIC 1
+#define LC_COLLATE 3
+#define LC_ALL     6
 #endif
-char * setlocale (int category, char const *locale);
+// *INDENT-ON*
 
-#endif // ! WITH_GLIBC
+char *setlocale (int category, char const *locale);
+
+#endif // ! SYSTEM_LIBC
 
 #endif // __MES_LOCALE_H
