@@ -21,14 +21,14 @@
 #ifndef __MES_STDINT_H
 #define __MES_STDINT_H 1
 
-#if WITH_GLIBC
+#if SYSTEM_LIBC
 #ifndef _GNU_SOURCE
 #define _GNU_SOURCE
 #endif
 #undef __MES_STDINT_H
 #include_next <stdint.h>
 
-#else // ! WITH_GLIBC
+#else // ! SYSTEM_LIBC
 
 #undef unsigned
 #undef uint8_t
@@ -58,28 +58,10 @@ typedef int int32_t;
 typedef unsigned long long uint64_t;
 typedef long long int64_t;
 
-#ifndef __MES_SIZE_T
-#define __MES_SIZE_T
-#undef size_t
-typedef unsigned long size_t;
-#endif
-
-#ifndef __MES_INTPTR_T
-#define __MES_INTPTR_T
-#undef intptr_t
-typedef long intptr_t;
-#endif
-
-// FIXME
 typedef int intmax_t;
 typedef unsigned uintmax_t;
-typedef unsigned* uintptr_t;
 
-#ifndef __MES_PTRDIFF_T
-#define __MES_PTRDIFF_T
-#undef ptrdiff_t
-typedef long ptrdiff_t;
-#endif
+#include <sys/types.h>
 
 #define CHAR_BIT 8
 #define CHAR_MAX 255
@@ -121,6 +103,6 @@ typedef long ptrdiff_t;
 #define SIZE_MAX UINT64_MAX
 #endif
 
-#endif // ! WITH_GLIBC
+#endif // ! SYSTEM_LIBC
 
 #endif // __MES_STDINT_H
