@@ -69,6 +69,7 @@ int fprintf (FILE * stream, char const *format, ...);
 int fpurge (FILE * stream);
 int fputc (int c, FILE * stream);
 int fputs (char const *s, FILE * stream);
+int fscanf (FILE * stream, char const *template, ...);
 int fseek (FILE * stream, long offset, int whence);
 int getc (FILE * stream);
 int getchar (void);
@@ -81,7 +82,7 @@ int remove (char const *file_name);
 int setvbuf (FILE * stream, char *buf, int mode, size_t size);
 int snprintf (char *str, size_t size, char const *format, ...);
 int sprintf (char *str, char const *format, ...);
-int sscanf (char const *str, const char *format, ...);
+int sscanf (char const *str, char const *format, ...);
 int ungetc (int c, FILE * stream);
 long ftell (FILE * stream);
 size_t fread (void *ptr, size_t size, size_t count, FILE * stream);
