@@ -85,10 +85,12 @@ struct stat
 int chmod (char const *file_name, mode_t mode);
 int fstat (int filedes, struct stat *buf);
 int mkdir (char const *file_name, mode_t mode);
+int mknod (char const *file_name, mode_t mode, dev_t dev);
 int chown (char const *file_name, uid_t owner, gid_t group);
 int rmdir (char const *file_name);
 int stat (char const *file_name, struct stat *buf);
 
+#define S_IFIFO 0010000
 #define S_IFCHR 0020000
 #define S_IFDIR 0040000
 #define S_IFBLK 0060000
@@ -96,6 +98,7 @@ int stat (char const *file_name, struct stat *buf);
 #define S_IFLNK 0120000
 #define S_IFMT  0170000
 
+#define S_ISFIFO(m) (((m) & S_IFMT) == S_IFIFO)
 #define S_ISDIR(m) (((m) & S_IFMT) == S_IFDIR)
 #define S_ISREG(m) (((m) & S_IFMT) == S_IFREG)
 
