@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2018 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2018,2019 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -18,10 +18,12 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <linux/syscall.h>
+#include <syscall.h>
 #include <time.h>
 
 int
 clock_gettime (clockid_t clk_id, struct timespec *tp)
 {
-  return _sys_call2 (SYS_clock_gettime, (long)clk_id, (long)tp);
+  return _sys_call2 (SYS_clock_gettime, (long) clk_id, (long) tp);
 }
