@@ -26,12 +26,16 @@ abtol (char const **p, int base)
 {
   char const *s = *p;
   int i = 0;
-  int sign = 1;
+  int sign_p = 0;
   if (!base)
     base = 10;
+  while (isspace (*s))
+    s++;
+  if (*s && *s == '+')
+    s++;
   if (*s && *s == '-')
     {
-      sign = -1;
+      sign_p = 1;
       s++;
     }
   while (isnumber (*s, base))
@@ -42,5 +46,5 @@ abtol (char const **p, int base)
       s++;
     }
   *p = s;
-  return i * sign;
+  return sign_p ? -i : i;
 }
