@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2016,2017,2018 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2016,2017,2018,2019 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -18,32 +18,42 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libmes.h>
+#include <assert.h>
+#include <mes/lib.h>
 
-char const*
+char *
 ntoab (long x, int base, int signed_p)
 {
   static char itoa_buf[20];
   char *p = itoa_buf + 11;
   *p-- = 0;
+  assert(base > 0);
 
-  int sign = 0;
-  unsigned long u = x;
+  int sign_p = 0;
+  unsigned long u;
   if (signed_p && x < 0)
     {
-      sign = 1;
+      sign_p = 1;
       u = -x;
     }
+  else
+    u = x;
 
   do
-     {
-       long i = u % base;
-       *p-- = i > 9 ? 'a' + i - 10 : '0' + i;
-       u = u / base;
-     } while (u);
+    {
+      unsigned long i;
+#if __MESC__ && __arm__
+      u = __mesabi_uldiv (u, (unsigned long) base, &i);
+#else
+      i = u % base;
+      u = u / base;
+#endif
+      *p-- = i > 9 ? 'a' + i - 10 : '0' + i;
+    }
+  while (u);
 
-  if (sign && *(p + 1) != '0')
+  if (sign_p && *(p + 1) != '0')
     *p-- = '-';
 
-  return p+1;
+  return p + 1;
 }
