@@ -18,12 +18,13 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libmes.h>
+#include <mes/lib.h>
+#include <string.h>
 
 int
-oputs (char const* s)
+oputs (char const *s)
 {
   int i = strlen (s);
-  write (g_stdout, s, i);
+  write (__stdout, s, i);
   return 0;
 }
