@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2017,2018 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2017,2018,2019 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -25,5 +25,8 @@
 int
 fflush (FILE * stream)
 {
-  fsync ((long) stream);
+  int filedes = (long) stream;
+  if (filedes < 3)
+    return 0;
+  return fsync (filedes);
 }
