@@ -21,6 +21,15 @@
 #include <mes/lib.h>
 #include <string.h>
 
+/* FIXME: We want bin/mes-mescc's x86-linux sha256sum to stay the same.
+   Therfore we cannot remove stdlib/malloc from libc_SOURCES, which is
+   what GNU suggests.
+
+   move stdlib/malloc.c to unix/malloc.c and move it from shared
+   libc_SOURCES to linux-specific list when the checksum of mes.c
+   changes. */
+
+#if !__GNU__
 char *__brk = 0;
 
 void *
@@ -34,3 +43,4 @@ malloc (size_t size)
   __brk += size;
   return p;
 }
+#endif /* !__GNU__ */
