@@ -18,9 +18,10 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* Taken from GNU C Library
- * Routines for dealing with '\0' separated arg vectors.
- * Written by Miles Bader <miles@gnu.ai.mit.edu>
+/** Commentary:
+    Taken from GNU C Library
+    Routines for dealing with '\0' separated arg vectors.
+    Written by Miles Bader <miles@gnu.org>
 */
 
 #include <argz.h>
@@ -40,5 +41,3 @@ __argz_count (const char *argz, size_t len)
     }
   return count;
 }
-
-libc_hidden_def (__argz_count) weak_alias (__argz_count, argz_count)
