@@ -18,10 +18,10 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libmes.h>
+#include <mes/lib.h>
 
 size_t
-strlen (char const* s)
+strlen (char const *s)
 {
   int i = 0;
   while (s[i])
