@@ -18,11 +18,12 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libmes.h>
+#include <mes/lib.h>
+#include <errno.h>
 #include <stdio.h>
 
 int
-fpurge (FILE *stream)
+fpurge (FILE * stream)
 {
   static int stub = 0;
   if (__mes_debug () && !stub)
