@@ -18,11 +18,11 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libmes.h>
+#include <mes/lib.h>
 #include <stdio.h>
 
 int
-setvbuf (FILE *stream, char *buf, int mode, size_t size)
+setvbuf (FILE * stream, char *buf, int mode, size_t size)
 {
   static int stub = 0;
   if (__mes_debug () && !stub)
