@@ -18,7 +18,8 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libmes.h>
+#include <mes/lib.h>
+#include <errno.h>
 #include <unistd.h>
 
 char *
@@ -30,6 +31,6 @@ ttyname (int filedes)
   stub = 1;
   errno = 0;
   if (isatty (filedes))
-      return "/dev/tty0";
+    return "/dev/tty0";
   return 0;
 }
