@@ -37,8 +37,12 @@
   (define-macro (mes-use-module . rest) #t)))
 
 (define %host-arch (or (getenv "%arch") %arch))
-(define %prefix (getenv "%prefix"))
-(define %version (getenv "%version"))
+(define %host-kernel (or (getenv "%kernel") "linux")) ;; FIXME
+(define %prefix (or (getenv "%prefix") "mes"))
+(define %includedir (or (getenv "%includedir") "include"))
+(define %libdir (or (getenv "%libdir") "."))
+(define %version (or (getenv "%version") "0.0"))
+(define %numbered-arch? (and=> (getenv "%numbered_arch") (lambda (x) (equal? x "true"))))
 
 (when (and=> (getenv "V") (lambda (v) (and (= (string-length v) 1) (> (string->number v) 1))))
   (format (current-error-port) "mescc[~a]...\n" %scheme))
@@ -63,6 +67,7 @@
             (debug-info (single-char #\g))
             (dumpmachine)
             (fno-builtin)
+            (fno-stack-protector)
             (help (single-char #\h))
             (include (single-char #\I) (value #t))
             (library-dir (single-char #\L) (value #t))
@@ -72,6 +77,7 @@
             (nostartfiles)
             (nostdinc)
             (nostdlib)
+            (numbered-arch?)
             (preprocess (single-char #\E))
             (static)
             (std (value #t))
@@ -97,9 +103,11 @@ C99 compiler in Scheme for bootstrapping the GNU system.
 Options:
   --align             align globals
   --arch=ARCH         compile for ARCH [~a]
+  --kernel=ARCH       compile for KERNEL [~a]
   -dumpmachine        display the compiler's target machine
   --base-address=ADRRESS
                       use BaseAddress ADDRESS [0x1000000]
+  --numbered-arch     mescc-tools use numbered arch
   -D DEFINE[=VALUE]   define DEFINE [VALUE=1]
   -E                  preprocess only; do not compile, assemble or link
   -g                  add debug info [GDB, objdump] TODO: hex2 footer
@@ -121,6 +129,7 @@ Options:
 
 Ignored for GCC compatibility
   -fno-builtin
+  -fno-stack-protector
   -no-pie
   -nostdinc
   -static
@@ -134,13 +143,14 @@ Environment variables:
 Report bugs to: bug-mes@gnu.org
 GNU Mes home page: <http://gnu.org/software/mes/>
 General help using GNU software: <http://gnu.org/gethelp/>
-" %host-arch)
+" %host-arch %host-kernel)
                 (exit (or (and usage? 2) 0)))
            options))))
 
 (define (mescc:main args)
   (let* ((single-dash-options '("-dumpmachine"
                                 "-fno-builtin"
+                                "-fno-stack-protector"
                                 "-no-pie"
                                 "-nodefaultlibs"
                                 "-nostartfiles"
@@ -155,8 +165,14 @@ General help using GNU software: <http://gnu.org/gethelp/>
          (args (append-map unclump-single args))
          (options (parse-opts args))
          (options (acons 'prefix %prefix options))
+         (options (acons 'includedir %includedir options))
+         (options (acons 'libdir %libdir options))
          (arch (option-ref options 'arch %host-arch))
          (options (if arch (acons 'arch arch options) options))
+         (kernel (option-ref options 'kernel %host-kernel))
+         (options (acons 'kernel kernel options))
+         (numbered-arch? (option-ref options 'numbered-arch? %numbered-arch?))
+         (options (acons 'numbered-arch? numbered-arch? options))
          (dumpmachine? (option-ref options 'dumpmachine #f))
          (preprocess? (option-ref options 'preprocess #f))
          (compile? (option-ref options 'compile #f))
@@ -171,3 +187,5 @@ General help using GNU software: <http://gnu.org/gethelp/>
           (compile? (mescc:compile options))
           (assemble? (mescc:assemble options))
           (else (mescc:link options)))))
+
+(define main mescc:main)
