@@ -35,9 +35,9 @@
             infos->M1
             M1:merge-infos))
 
-(define* (infos->M1 file-name infos #:key align?)
+(define* (infos->M1 file-name infos #:key align? verbose?)
   (let ((info (fold M1:merge-infos (make <info>) infos)))
-    (info->M1 file-name info #:align? align?)))
+    (info->M1 file-name info #:align? align? #:verbose? verbose?)))
 
 (define (M1:merge-infos o info)
   (clone info
@@ -81,13 +81,16 @@
   (if hex? (string-append "%0x" (dec->hex o))
       (string-append "%" (number->string o))))
 
+(define mesc? (string=? %compiler "mesc"))
+
 (define (hex2:immediate8 o)
-  (if hex? (string-append "%0x" (dec->hex (modulo o #x100000000))
+  ;; FIXME: #x100000000 => 0 divide-by-zero when compiled with 64 bit mesc
+  (if hex? (string-append "%0x" (dec->hex (if mesc? 0 (modulo o #x100000000)))
                           " %0x" (if (< o 0) "-1"
-                                     (dec->hex (quotient o #x100000000))))
-      (string-append "%" (number->string (dec->hex (modulo o #x100000000)))
+                                     (dec->hex (if mesc? o (quotient o #x100000000)))))
+      (string-append "%" (number->string (dec->hex (if mesc? 0 (modulo o #x100000000))))
                      " %" (if (< o 0) "-1"
-                              (number->string (dec->hex (quoteint o #x100000000)))))))
+                              (number->string (dec->hex (if mesc? o (quotient o #x100000000))))))))
 
 (define* (display-join o #:optional (sep ""))
   (let loop ((o o))
@@ -97,12 +100,19 @@
           (display sep))
       (loop (cdr o)))))
 
-(define* (info->M1 file-name o #:key align?)
+(define (global-string? o)
+  (and (pair? o) (pair? (car o)) (eq? (caar o) #:string)))
+
+(define (global-extern? o)
+  (and=> (global:storage o) (cut eq? <> 'extern)))
+
+(define* (info->M1 file-name o #:key align? verbose?)
   (let* ((functions (.functions o))
          (function-names (map car functions))
          (globals (.globals o))
-         (global-names (map car globals))
-         (strings (filter (lambda (g) (and (pair? g) (eq? (car g) #:string))) global-names))
+         (globals (filter (negate (compose global-extern? cdr)) globals))
+         (strings (filter global-string? globals))
+         (strings (map car strings))
          (reg-size (type:size (assoc-ref (.types o) "*"))))
     (define (string->label o)
       (let ((index (list-index (lambda (s) (equal? s o)) strings)))
@@ -111,6 +121,7 @@
             (if (equal? o "%0") o       ; FIXME: 64b
                 (error "no such string:" o)))))
     (define (text->M1 o)
+      ;;
       (cond
        ((char? o) (text->M1 (char->integer o)))
        ((string? o) o)
@@ -166,7 +177,8 @@
           ((#:immediate4 ,immediate4) (hex2:immediate4 immediate4))
           ((#:immediate8 ,immediate8) (hex2:immediate8 immediate8))
           (_ (error "text->M1 no match o" o))))
-       ((pair? o) (string-join (map text->M1 o)))))
+       ((pair? o) (string-join (map text->M1 o)))
+       (#t (error "no such text:" o))))
     (define (write-function o)
       (let ((name (car o))
             (text (function:text (cdr o))))
@@ -181,7 +193,8 @@
                  (display-join (map text->M1 o) " "))
                 (else (error "line->M1 invalid line:" o)))
           (newline))
-        (display (string-append "    :" name "\n") (current-error-port))
+        (when verbose?
+          (display (string-append "    :" name "\n") (current-error-port)))
         (display (string-append "\n\n:" name "\n"))
         (for-each line->M1 (apply append text))))
     (define (write-global o)
@@ -207,8 +220,8 @@
                      ((global? (cdr o)) (global->string (cdr o)))
                      (else (car o))))
              (string? (string-prefix? "_string" label))
-             (foo (if (not (eq? (car (string->list label)) #\_))
-                      (display (string-append "    :" label "\n") (current-error-port))))
+             (foo (when (and verbose? (not (eq? (car (string->list label)) #\_)))
+                    (display (string-append "    :" label "\n") (current-error-port))))
              (data ((compose global:value cdr) o))
              (data (filter-map labelize data))
              (len (length data))
@@ -231,10 +244,13 @@
               (display-join  text " ")
               (display-align (length text))))
         (newline)))
-    (display "M1: functions\n" (current-error-port))
+    (when verbose?
+      (display "M1: functions\n" (current-error-port)))
     (for-each write-function (filter cdr functions))
     (when (assoc-ref functions "main")
       (display "\n\n:ELF_data\n") ;; FIXME
       (display "\n\n:HEX2_data\n"))
-    (display "M1: globals\n" (current-error-port))
-    (for-each write-global globals)))
+    (when verbose?
+      (display "M1: globals\n" (current-error-port)))
+    (for-each write-global (filter global-string? globals))
+    (for-each write-global (filter (negate global-string?) globals))))
