@@ -18,18 +18,12 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-int
-test ()
-{
-  return 2;
-}
+//V=2 CC32=i686-unknown-linux-gnu-gcc build-aux/cc32-mes.sh scaffold/main
+//V=2 CC64=gcc build-aux/cc64-mes.sh scaffold/main
 
 int
 main (int argc, char *argv[])
 {
-  if (argc == 6) return 42;
-  int a = 39;
-  if (argc > 1) a+=argc;
-  else a++;
-  return a + test ();
+  argc = 42;
+  return argc;
 }
