@@ -25,12 +25,13 @@
 int
 main (int argc, char *argv[])
 {
-  g_stdin = open ("scaffold/read.data", 0);
+  __stdin = open ("scaffold/read.data", 0);
   int c = getchar ();
   if (c != 'm')
     return 1;
-  while (c != EOF) {
-    putchar (c);
-    c = getchar ();
-  }
+  while (c != EOF)
+    {
+      putchar (c);
+      c = getchar ();
+    }
 }
